#!/usr/bin/env python

import errno
import os
import shutil
import signal
import sys
import traceback
import time

CHROOT = os.getenv('CHROOT')

basedir = os.environ.get('BASEDIR') or 'child'
starting_pt = CHROOT and '/' or os.path.join(os.getcwd(), basedir)
final_destination = os.path.join(basedir, 'child1')
if os.path.exists(basedir):
    shutil.rmtree(basedir.split(os.path.sep)[0])
os.makedirs(basedir, 0700)
os.symlink('../child', final_destination)
child_pid = os.fork()
if child_pid:
    time.sleep(5)
    try:
        if os.getenv('MUSICAL_CHAIRS'):
            print '[parent,before] inode is:', os.stat(basedir).st_ino
        shutil.rmtree(basedir.split(os.path.sep)[0])
        if os.getenv('MUSICAL_CHAIRS'):
            os.makedirs(basedir, 0700)
            print '[parent,after] inode is:', os.stat(basedir).st_ino
    except:
        sys.stdout.write(traceback.print_exc())
        os.kill(child_pid, signal.SIGKILL)
        sys.exit(2)
else:

    fd = os.open(starting_pt, os.O_RDONLY)
    if CHROOT:
        os.chroot('.')
    os.chdir(final_destination)

    time.sleep(10)
    if os.getenv('MUSICAL_CHAIRS'):
        # Can't do this in python because os.path.{abs,rel}path/os.stat fails
        # if the path is missing ;).
        print '[child] inode from fstat is:', os.fstat(fd).st_ino
        os.system('echo \[child\] inode from stat is: `stat -f %%i %s`'
                  % (starting_pt, ))

    signal.alarm(5)
    try:
        print os.getcwd()
        print 'did not fail when calling getcwd()'
    except OSError as ose:
        if ose.errno != errno.ENOENT:
            raise
    try:
        os.chdir('.')
        print 'did not fail with chdir(.)'
    except OSError as ose:
        if ose.errno != errno.ENOENT:
            raise
    try:
        os.chdir('../..')
        print 'did not fail with chdir(../..)'
    except OSError as ose:
        if ose.errno != errno.ENOENT:
            raise
    try:
        print 'cwd after is', os.getcwd()
    except OSError as ose:
        print 'indeterminate'
    signal.alarm(0)
    os._exit(0)

sys.exit(os.waitpid(child_pid, 0)[1])
